//
//  MyCustomIndicator.m
//  Week6_QuartzAnimationTouches
//
//  Created by Jason Fieldman on 2/17/10.
//  Copyright 2010 __MyCompanyName__. All rights reserved.
//

#import "MyCustomIndicator.h"


@implementation MyCustomIndicator


- (id)initWithFrame:(CGRect)frame {
    if (self = [super initWithFrame:frame]) {
		progressPosition = 0;
		animationTimer = nil;
    }
    return self;
}


- (void) triggerTimer:(NSTimer*)timer {
	progressPosition++;
	[self setNeedsDisplay];
}

- (void) startAnimating {
	if (animationTimer) return;
	animationTimer = [NSTimer scheduledTimerWithTimeInterval:kAnimDelay target:self selector:@selector(triggerTimer:) userInfo:nil repeats:YES];
}

- (void) stopAnimating {
	if (!animationTimer) return;
	[animationTimer invalidate];
	animationTimer = nil;
}


- (void)drawRect:(CGRect)rect {
	float width = self.frame.size.width;
	float height = self.frame.size.height;
	
	float smallest_dimension = (width > height) ? height : width;
	float radius = (smallest_dimension / 2) * 0.65;
	float petalSize = radius * 0.5;
	
	float center_x = width / 2;
	float center_y = height / 2;
	
	CGContextRef c = UIGraphicsGetCurrentContext();
	
	float angle = progressPosition * kPetalInc;
	float color = 1;
	
	for (int p = 0; p < kNumPetals; p++) {
		
		float petal_center_x = center_x + (radius * cos(angle));
		float petal_center_y = center_y + (radius * sin(angle));
		
		CGRect petalRect = CGRectMake(petal_center_x - (petalSize/2),
									  petal_center_y - (petalSize/2),
									  petalSize,
									  petalSize);
		
		CGContextSetRGBFillColor(c, color, color, color, 1);
		CGContextFillEllipseInRect(c, petalRect);
		
		color -= kPetalColorDec;
		angle += kPetalInc;
	}
}


- (void)dealloc {
    [super dealloc];
}


@end
